extern const char **_dictionary_conectiva;
#ifndef DICTIONARY_REQUEST
	#define DICTIONARY_REQUEST \
	const char **_dictionary_conectiva;\
	TRANSLATE_SYSTEM_REQ _dictionary_req_conectiva("conectiva",_dictionary_conectiva,38,0);\
	void dummy_dict_conectiva(){}
#endif
#ifndef MSG_U
	#define MSG_U(id,m)	_dictionary_conectiva[id]
	#define MSG_B(id,m,n)	_dictionary_conectiva[id]
	#define MSG_R(id)	_dictionary_conectiva[id]
	#define P_MSG_U(id,m)	new_trans_notload(_dictionary_conectiva,id)
	#define P_MSG_B(id,m,n)	new_trans_notload(_dictionary_conectiva,id)
	#define P_MSG_R(id)	new_trans_notload(_dictionary_conectiva,id)
#endif
#define T_USAGE	0
#define I_REMOVING	1
#define T_AUTHENTICATE	2
#define I_AUTHREQ	3
#define T_NEWPASS	4
#define I_NEWPASS	5
#define I_DISABLED	6
#define I_ENABLED	7
#define P_CTRLSERV	8
#define I_RUNNING	9
#define I_SYSVENABLED	10
#define I_SYSVDISABLED	11
#define T_SERVNAME	12
#define F_STATUS	13
#define B_START	14
#define B_STOP	15
#define B_RESTART	16
#define B_STATUS	17
#define T_ONESERVICE	18
#define I_ONESERVICE	19
#define F_CONFIGURED	20
#define F_DESCRIPTION	21
#define F_PACKAGE	22
#define F_PKGVER	23
#define I_NOMANAGERPM	24
#define B_PKGINFO	25
#define I_CUSTOMLEVELS	26
#define I_BASE	27
#define I_RUNLEVELS	28
#define I_LEVEL0	29
#define I_LEVEL1	30
#define I_LEVEL2	31
#define I_LEVEL3	32
#define I_LEVEL4	33
#define I_LEVEL5	34
#define I_LEVEL6	35
#define F_RUNLEVEL	36
#define I_RECOMMENDED	37
